﻿Option Strict On

Imports Nist.Logging
Imports System.Xml

'Contains VERY basic methods whichs tests class 2/5 operations with the BIAS Service (.NET)
Module EntryPoint
    Dim client As BIAS_v1Client

    Sub Main()
        client = New BIAS_v1Client

        TestQueryCapabilities() : System.Console.WriteLine()
        TestEnroll() : System.Console.WriteLine()
        TestVerify() : System.Console.WriteLine()
        TestRetrieveInformation() : System.Console.WriteLine()
        TestIdentify() : System.Console.WriteLine()

        client.Close()
    End Sub

    Public Sub TestIdentify()
        Debug("TestIdentify()")
        Info("Identifying subject...")

        Dim InputPackage As New IdentifyRequest()
        InputPackage.ProcessingOptions = New String() {}

        Dim InputData = <InputData xmlns="http://docs.oasis-open.org/bias/ns/bias-1.0/">
                            <DataType>image/jpeg</DataType>
                            <Data>cXdlcnRhc3Jnc2RmZ2Flc2Zna3UzMjU3ODk0NTYgb2ZnZHUgamt4bmggaSBlNDA4NnJzdGlvaCB4a2NqZ24gbzg1NCA=</Data>
                        </InputData>

        InputPackage.InputData = CType(New XmlDocument().ReadNode(InputData.CreateReader()), XmlElement)

        Dim Result As IdentifyResponsePackage = client.Identify(InputPackage)

        If Result.ResponseStatus.Return = 0 Then
            Dim ReturnData As XElement = XElement.Load(Result.ReturnData.CreateNavigator().ReadSubtree())
            Info("Subject identified as {0} [{1}]", ReturnData.<SubjectInformation>.<Name>.Value, ReturnData.<SubjectInformation>.<MD5>.Value)
        Else
            Info("Subject unable to be identified")
        End If

    End Sub

    Public Sub TestVerify()
        Debug("TestVerify()")
        Info("Verifying subject...")
        Dim InputPackage As New VerifyRequest()
        InputPackage.ProcessingOptions = New String() {}

        Dim InputData = <InputData xmlns="http://docs.oasis-open.org/bias/ns/bias-1.0/">
                            <Name>John Doe</Name>
                            <MD5>d41d8cd98f00b204e9800998ecf8427e</MD5>
                            <DataType>image/jpeg</DataType>
                            <Data>cXdlcnRhc3Jnc2RmZ2Flc2Zna3UzMjU3ODk0NTYgb2ZnZHUgamt4bmggaSBlNDA4NnJzdGlvaCB4a2NqZ24gbzg1NCA=</Data>
                        </InputData>

        InputPackage.InputData = CType(New XmlDocument().ReadNode(InputData.CreateReader()), XmlElement)

        InputPackage.Identity = New BIASIdentity
        InputPackage.Identity.IdentityClaim = "d41d8cd98f00b204e9800998ecf8427e"

        Dim Result As VerifyResponsePackage = client.Verify(InputPackage)

        Info("Subject verified? {0}", Result.Match)
        Info("Match score: {0}", Result.Score)

    End Sub

    Public Sub TestRetrieveInformation()
        Debug("TestRetrieveInformation()")
        Info("Retrieving information...")

        Dim InputPacakge As New RetrieveInformationRequest()
        InputPacakge.ProcessingOptions = New String() {}
        InputPacakge.Identity = New BIASIdentity()
        InputPacakge.Identity.SubjectID = "d41d8cd98f00b204e9800998ecf8427e"

        Dim Result As RetrieveInformationResponsePackage = client.RetrieveInformation(InputPacakge)

        Dim ReturnData As XElement = XElement.Load(Result.ReturnData.CreateNavigator().ReadSubtree())
        Info("{0} data elements returned", ReturnData.<SubjectInformation>.Elements().Count)

        For Each ReturnDataElement As XElement In ReturnData.<SubjectInformation>.Elements()
            Info(" - {0}", ReturnDataElement.Name.ToString(), ReturnDataElement.Value)
        Next
    End Sub

    Public Sub TestEnroll()
        Debug("TestEnroll()")
        Info("Creating input package...")
        Dim InputPackage As New EnrollRequest()
        InputPackage.ProcessingOptions = New String() {}

        Dim InputData = <InputData xmlns="http://docs.oasis-open.org/bias/ns/bias-1.0/">
                            <Name>John Doe</Name>
                            <MD5>d41d8cd98f00b204e9800998ecf8427e</MD5>
                            <DataType>image/jpeg</DataType>
                            <Data>cXdlcnRhc3Jnc2RmZ2Flc2Zna3UzMjU3ODk0NTYgb2ZnZHUgamt4bmggaSBlNDA4NnJzdGlvaCB4a2NqZ24gbzg1NCA=</Data>
                        </InputData>

        InputPackage.InputData = CType(New XmlDocument().ReadNode(InputData.CreateReader()), XmlElement)

        Info("Enrolling subject...")
        Dim Result As EnrollResponsePackage = client.Enroll(InputPackage)

        If Result.ResponseStatus.Return = 0 Then
            Info("Enrollment successful!")
        Else
            Info("Enrollment failed: {0}", Result.ResponseStatus.Message)
        End If

    End Sub

    Public Sub TestQueryCapabilities()
        Debug("TestQueryCapabilities()")
        Info("Querying for capabilities...")
        Dim Result As QueryCapabilitiesResponsePackage = client.QueryCapabilities(Nothing)

        If Result IsNot Nothing Then
            Info("{0} Capabilities Available", Result.CapabilityList.Count)

            For Each C As CapabilityType In Result.CapabilityList
                Info(" - {0}", C.CapabilityName.ToString())
            Next
        End If
    End Sub
End Module